@@ -22,8 +22,14 @@ class SkillResponseType:
 
 class SkillRequestType:
     class User:
+
+        class Client:
+            name: str
+            type: str
+            _meta_: dict
+
         user_id: str
-        client: dict
+        client: Client
         global_id: str
 
     class Update:
